==> apeman-app-recover-3.0.1.tgz: package/lib/doing/do_create_recover.js <==
/**
 * @function doCreateRecover
 */
'use strict'

const co = require('co')
const uuid = require('uuid')
const successPayload = require('apeman-app-rest/lib/payloads/success_payload')
const failurePayload = require('apeman-app-rest/lib/payloads/failure_payload')
const apemanmodel = require('apemanmodel')
const validateDataType = require('apeman-app-rest/lib/validating/validate_data_type')
const errors = require('../errors')

/** @lends doCreateRecover */
function doCreateRecover (config) {
  const ACTION_NAME = 'create'
  let success = successPayload(ACTION_NAME)
  let failure = failurePayload(ACTION_NAME)

  let expireDuration = config.expireDuration
  return function createRecover (UserRecover, context) {
    let update = apemanmodel.defineUpdate(UserRecover, context.transaction)

    const User = UserRecover.getRef('user').model
    let data = context.data
    let email = data.attributes.email
    return co(function * () {
      let user = yield User.findOne({
        where: { email }
      })
      if (!user) {
        return failure(
          errors.notFoundError(apemanmodel.toType(User), { email })
        )
      }

      let typeError = validateDataType(data, apemanmodel.toType(UserRecover))
      if (typeError) {
        return failure(typeError)
      }
      let userId = user.id
      let token = uuid.v4().replace(/\-/g, '')
      let recovers = yield UserRecover.findOrCreate({
        where: { userId },
        defaults: { userId, token }
      })
      let recover = [].concat(recovers || [])[ 0 ]
      let updated = yield update(recover, {
        expireAt: new Date(new Date().getTime() + expireDuration),
        token: token,
        done: false
      })
      return success(
        {},
        apemanmodel.toData(UserRecover, updated)
      )
    })
  }
}

module.exports = doCreateRecover

==> apeman-app-recover-4.0.2.tgz: package/lib/doing/do_create_recover.js <==
/**
 * @function doCreateRecover
 * @returns {function}
 */
'use strict'

const co = require('co')
const uuid = require('uuid')
const successPayload = require('apeman-app-rest/lib/payloads/success_payload')
const failurePayload = require('apeman-app-rest/lib/payloads/failure_payload')
const apemanmodel = require('apemanmodel')
const validateDataType = require('apeman-app-rest/lib/validating/validate_data_type')
const errors = require('../errors')

/** @lends doCreateRecover */
function doCreateRecover (config) {
  const ACTION_NAME = 'create'
  let success = successPayload(ACTION_NAME)
  let failure = failurePayload(ACTION_NAME)

  let expireDuration = config.expireDuration
  return function createRecover (UserRecover, context) {
    let { data, transaction } = context
    let update = apemanmodel.defineUpdate(UserRecover, transaction)

    const User = UserRecover.getRef('user').model
    let email = data.attributes.email
    return co(function * () {
      let user = yield User.findOne({
        where: { email }
      })
      if (!user) {
        return failure(
          errors.notFoundError(apemanmodel.toType(User), { email })
        )
      }

      let typeError = validateDataType(data, apemanmodel.toType(UserRecover))
      if (typeError) {
        return failure(typeError)
      }
      let userId = user.id
      let token = uuid.v4().replace(/\-/g, '')
      let recovers = yield UserRecover.findOrCreate({
        where: { userId },
        defaults: { userId, token }
      })
      let recover = [].concat(recovers || [])[ 0 ]
      let updated = yield update(recover, {
        token,
        expireAt: new Date(new Date().getTime() + expireDuration),
        done: false
      })
      return success(
        {},
        apemanmodel.toData(UserRecover, updated)
      )
    })
  }
}

module.exports = doCreateRecover
